@@ -3,11 +3,20 @@ from django.template.loader import render_to_string
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib import comments
-from django.utils.encoding import smart_unicode
+from django.utils import six
+from django.utils.deprecation import RenameMethodsBase, RemovedInDjango18Warning
+from django.utils.encoding import smart_text
 
 register = template.Library()
 
-class BaseCommentNode(template.Node):
+
+class RenameBaseCommentNodeMethods(RenameMethodsBase):
+    renamed_methods = (
+        ('get_query_set', 'get_queryset', RemovedInDjango18Warning),
+    )
+
+
+class BaseCommentNode(six.with_metaclass(RenameBaseCommentNodeMethods, template.Node)):
     """
     Base helper class (abstract) for handling the get_comment_* template tags.
     Looks a bit strange, but the subclasses below should make this a bit more
@@ -17,7 +26,7 @@ class BaseCommentNode(template.Node):
     @classmethod
     def handle_token(cls, parser, token):
         """Class method to parse get_comment_list/count/form and return a Node."""
-        tokens = token.contents.split()
+        tokens = token.split_contents()
         if tokens[1] != 'for':
             raise template.TemplateSyntaxError("Second argument in %r tag must be 'for'" % tokens[0])
 
@@ -26,8 +35,8 @@ class BaseCommentNode(template.Node):
             if tokens[3] != 'as':
                 raise template.TemplateSyntaxError("Third argument in %r must be 'as'" % tokens[0])
             return cls(
-                object_expr = parser.compile_filter(tokens[2]),
-                as_varname = tokens[4],
+                object_expr=parser.compile_filter(tokens[2]),
+                as_varname=tokens[4],
             )
 
         # {% get_whatever for app.model pk as varname %}
@@ -35,9 +44,9 @@ class BaseCommentNode(template.Node):
             if tokens[4] != 'as':
                 raise template.TemplateSyntaxError("Fourth argument in %r must be 'as'" % tokens[0])
             return cls(
-                ctype = BaseCommentNode.lookup_content_type(tokens[2], tokens[0]),
-                object_pk_expr = parser.compile_filter(tokens[3]),
-                as_varname = tokens[5]
+                ctype=BaseCommentNode.lookup_content_type(tokens[2], tokens[0]),
+                object_pk_expr=parser.compile_filter(tokens[3]),
+                as_varname=tokens[5]
             )
 
         else:
@@ -64,19 +73,19 @@ class BaseCommentNode(template.Node):
         self.comment = comment
 
     def render(self, context):
-        qs = self.get_query_set(context)
+        qs = self.get_queryset(context)
         context[self.as_varname] = self.get_context_value_from_queryset(context, qs)
         return ''
 
-    def get_query_set(self, context):
+    def get_queryset(self, context):
         ctype, object_pk = self.get_target_ctype_pk(context)
         if not object_pk:
             return self.comment_model.objects.none()
 
         qs = self.comment_model.objects.filter(
-            content_type = ctype,
-            object_pk    = smart_unicode(object_pk),
-            site__pk     = settings.SITE_ID,
+            content_type=ctype,
+            object_pk=smart_text(object_pk),
+            site__pk=settings.SITE_ID,
         )
 
         # The is_public and is_removed fields are implementation details of the
@@ -103,7 +112,7 @@ class BaseCommentNode(template.Node):
 
     def get_context_value_from_queryset(self, context, qs):
         """Subclasses should override this."""
-        raise NotImplementedError
+        raise NotImplementedError('subclasses of BaseCommentNode must provide a get_context_value_from_queryset() method')
 
 class CommentListNode(BaseCommentNode):
     """Insert a list of comments into the context."""
@@ -146,7 +155,7 @@ class RenderCommentFormNode(CommentFormNode):
     @classmethod
     def handle_token(cls, parser, token):
         """Class method to parse render_comment_form and return a Node."""
-        tokens = token.contents.split()
+        tokens = token.split_contents()
         if tokens[1] != 'for':
             raise template.TemplateSyntaxError("Second argument in %r tag must be 'for'" % tokens[0])
 
@@ -157,8 +166,8 @@ class RenderCommentFormNode(CommentFormNode):
         # {% render_comment_form for app.models pk %}
         elif len(tokens) == 4:
             return cls(
-                ctype = BaseCommentNode.lookup_content_type(tokens[2], tokens[0]),
-                object_pk_expr = parser.compile_filter(tokens[3])
+                ctype=BaseCommentNode.lookup_content_type(tokens[2], tokens[0]),
+                object_pk_expr=parser.compile_filter(tokens[3])
             )
 
     def render(self, context):
@@ -182,7 +191,7 @@ class RenderCommentListNode(CommentListNode):
     @classmethod
     def handle_token(cls, parser, token):
         """Class method to parse render_comment_list and return a Node."""
-        tokens = token.contents.split()
+        tokens = token.split_contents()
         if tokens[1] != 'for':
             raise template.TemplateSyntaxError("Second argument in %r tag must be 'for'" % tokens[0])
 
@@ -193,8 +202,8 @@ class RenderCommentListNode(CommentListNode):
         # {% render_comment_list for app.models pk %}
         elif len(tokens) == 4:
             return cls(
-                ctype = BaseCommentNode.lookup_content_type(tokens[2], tokens[0]),
-                object_pk_expr = parser.compile_filter(tokens[3])
+                ctype=BaseCommentNode.lookup_content_type(tokens[2], tokens[0]),
+                object_pk_expr=parser.compile_filter(tokens[3])
             )
 
     def render(self, context):
@@ -205,7 +214,7 @@ class RenderCommentListNode(CommentListNode):
                 "comments/%s/list.html" % ctype.app_label,
                 "comments/list.html"
             ]
-            qs = self.get_query_set(context)
+            qs = self.get_queryset(context)
             context.push()
             liststr = render_to_string(template_search_list, {
                 "comment_list" : self.get_context_value_from_queryset(context, qs)
@@ -329,4 +338,3 @@ def get_comment_permalink(comment, anchor_pattern=None):
     if anchor_pattern:
         return comment.get_absolute_url(anchor_pattern)
     return comment.get_absolute_url()
-
