@@ -13,7 +13,7 @@ from django.core.servers.basehttp import run, get_internal_wsgi_application
 from django.db import connections, DEFAULT_DB_ALIAS
 from django.db.migrations.executor import MigrationExecutor
 from django.utils import autoreload
-from django.utils.encoding import get_system_encoding
+from django.utils.encoding import force_text, get_system_encoding
 from django.utils import six
 from django.core.exceptions import ImproperlyConfigured
 
@@ -142,7 +142,7 @@ class Command(BaseCommand):
             try:
                 error_text = ERRORS[e.errno]
             except KeyError:
-                error_text = str(e)
+                error_text = force_text(e)
             self.stderr.write("Error: %s" % error_text)
             # Need to use an OS exit because sys.exit doesn't work in a thread
             os._exit(1)
