@@ -3,13 +3,14 @@ import unittest
 
 from django.test import TransactionTestCase
 from django.db import connection, DatabaseError, IntegrityError, OperationalError
-from django.db.models.fields import IntegerField, TextField, CharField, SlugField, BooleanField, BinaryField
+from django.db.models.fields import (BinaryField, BooleanField, CharField, IntegerField,
+    PositiveIntegerField, SlugField, TextField)
 from django.db.models.fields.related import ManyToManyField, ForeignKey
 from django.db.transaction import atomic
-from .models import (Author, AuthorWithM2M, Book, BookWithLongName,
+from .models import (Author, AuthorWithDefaultHeight, AuthorWithM2M, Book, BookWithLongName,
     BookWithSlug, BookWithM2M, Tag, TagIndexed, TagM2MTest, TagUniqueRename,
     UniqueTest, Thing, TagThrough, BookWithM2MThrough, AuthorTag, AuthorWithM2MThrough,
-    AuthorWithEvenLongerName, BookWeak)
+    AuthorWithEvenLongerName, BookWeak, Note)
 
 
 class SchemaTests(TransactionTestCase):
@@ -422,6 +423,76 @@ class SchemaTests(TransactionTestCase):
         self.assertEqual(columns['name'][0], "TextField")
         self.assertEqual(bool(columns['name'][1][6]), False)
 
+    def test_alter_text_field(self):
+        # Regression for "BLOB/TEXT column 'info' can't have a default value")
+        # on MySQL.
+        new_field = TextField(blank=True)
+        new_field.set_attributes_from_name("info")
+        with connection.schema_editor() as editor:
+            editor.alter_field(
+                Note,
+                Note._meta.get_field_by_name("info")[0],
+                new_field,
+                strict=True,
+            )
+
+    def test_alter_null_to_not_null(self):
+        """
+        #23609 - Tests handling of default values when altering from NULL to NOT NULL.
+        """
+        # Create the table
+        with connection.schema_editor() as editor:
+            editor.create_model(Author)
+        # Ensure the field is right to begin with
+        columns = self.column_classes(Author)
+        self.assertTrue(columns['height'][1][6])
+        # Create some test data
+        Author.objects.create(name='Not null author', height=12)
+        Author.objects.create(name='Null author')
+        # Verify null value
+        self.assertEqual(Author.objects.get(name='Not null author').height, 12)
+        self.assertIsNone(Author.objects.get(name='Null author').height)
+        # Alter the height field to NOT NULL with default
+        new_field = PositiveIntegerField(default=42)
+        new_field.set_attributes_from_name("height")
+        with connection.schema_editor() as editor:
+            editor.alter_field(
+                Author,
+                Author._meta.get_field_by_name("height")[0],
+                new_field
+            )
+        # Ensure the field is right afterwards
+        columns = self.column_classes(Author)
+        self.assertFalse(columns['height'][1][6])
+        # Verify default value
+        self.assertEqual(Author.objects.get(name='Not null author').height, 12)
+        self.assertEqual(Author.objects.get(name='Null author').height, 42)
+
+    @unittest.skipUnless(connection.features.supports_combined_alters, "No combined ALTER support")
+    def test_alter_null_to_not_null_keeping_default(self):
+        """
+        #23738 - Can change a nullable field with default to non-nullable
+        with the same default.
+        """
+        # Create the table
+        with connection.schema_editor() as editor:
+            editor.create_model(AuthorWithDefaultHeight)
+        # Ensure the field is right to begin with
+        columns = self.column_classes(AuthorWithDefaultHeight)
+        self.assertTrue(columns['height'][1][6])
+        # Alter the height field to NOT NULL keeping the previous default
+        new_field = PositiveIntegerField(default=42)
+        new_field.set_attributes_from_name("height")
+        with connection.schema_editor() as editor:
+            editor.alter_field(
+                AuthorWithDefaultHeight,
+                AuthorWithDefaultHeight._meta.get_field_by_name("height")[0],
+                new_field,
+            )
+        # Ensure the field is right afterwards
+        columns = self.column_classes(AuthorWithDefaultHeight)
+        self.assertFalse(columns['height'][1][6])
+
     @unittest.skipUnless(connection.features.supports_foreign_keys, "No FK support")
     def test_alter_fk(self):
         """
@@ -464,6 +535,29 @@ class SchemaTests(TransactionTestCase):
         else:
             self.fail("No FK constraint for author_id found")
 
+    def test_alter_implicit_id_to_explicit(self):
+        """
+        Should be able to convert an implicit "id" field to an explicit "id"
+        primary key field.
+        """
+        with connection.schema_editor() as editor:
+            editor.create_model(Author)
+
+        new_field = IntegerField(primary_key=True)
+        new_field.set_attributes_from_name("id")
+        new_field.model = Author
+        with connection.schema_editor() as editor:
+            editor.alter_field(
+                Author,
+                Author._meta.get_field_by_name("id")[0],
+                new_field,
+                strict=True,
+            )
+
+        # This will fail if DROP DEFAULT is inadvertently executed on this
+        # field which drops the id sequence, at least on PostgreSQL.
+        Author.objects.create(name='Foo')
+
     def test_rename(self):
         """
         Tests simple altering of fields
@@ -1040,3 +1134,77 @@ class SchemaTests(TransactionTestCase):
             DatabaseError,
             lambda: list(Thing.objects.all()),
         )
+
+    @unittest.skipUnless(connection.features.supports_foreign_keys, "No FK support")
+    def test_remove_constraints_capital_letters(self):
+        """
+        #23065 - Constraint names must be quoted if they contain capital letters.
+        """
+        def get_field(*args, **kwargs):
+            kwargs['db_column'] = "CamelCase"
+            field = kwargs.pop('field_class', IntegerField)(*args, **kwargs)
+            field.set_attributes_from_name("CamelCase")
+            return field
+
+        model = Author
+        field = get_field()
+        table = model._meta.db_table
+        column = field.column
+
+        with connection.schema_editor() as editor:
+            editor.create_model(model)
+            editor.add_field(model, field)
+
+            editor.execute(
+                editor.sql_create_index % {
+                    "table": editor.quote_name(table),
+                    "name": editor.quote_name("CamelCaseIndex"),
+                    "columns": editor.quote_name(column),
+                    "extra": "",
+                }
+            )
+            editor.alter_field(model, get_field(db_index=True), field)
+
+            editor.execute(
+                editor.sql_create_unique % {
+                    "table": editor.quote_name(table),
+                    "name": editor.quote_name("CamelCaseUniqConstraint"),
+                    "columns": editor.quote_name(field.column),
+                }
+            )
+            editor.alter_field(model, get_field(unique=True), field)
+
+            editor.execute(
+                editor.sql_create_fk % {
+                    "table": editor.quote_name(table),
+                    "name": editor.quote_name("CamelCaseFKConstraint"),
+                    "column": editor.quote_name(column),
+                    "to_table": editor.quote_name(table),
+                    "to_column": editor.quote_name(model._meta.auto_field.column),
+                }
+            )
+            editor.alter_field(model, get_field(Author, field_class=ForeignKey), field)
+
+    def test_add_field_use_effective_default(self):
+        """
+        #23987 - effective_default() should be used as the field default when
+        adding a new field.
+        """
+        # Create the table
+        with connection.schema_editor() as editor:
+            editor.create_model(Author)
+        # Ensure there's no surname field
+        columns = self.column_classes(Author)
+        self.assertNotIn("surname", columns)
+        # Create a row
+        Author.objects.create(name='Anonymous1')
+        # Add new CharField to ensure default will be used from effective_default
+        new_field = CharField(max_length=15, blank=True)
+        new_field.set_attributes_from_name("surname")
+        with connection.schema_editor() as editor:
+            editor.add_field(Author, new_field)
+        # Ensure field was added with the right default
+        with connection.cursor() as cursor:
+            cursor.execute("SELECT surname FROM schema_author;")
+            item = cursor.fetchall()[0]
+            self.assertEqual(item[0], None if connection.features.interprets_empty_strings_as_nulls else '')
